Exception: Risenexa::Tracking::StartupNotFoundError
- Defined in:
- lib/risenexa/tracking/errors.rb
Overview
Raised when the startup is not found for this account (HTTP 404). Non-retryable — wrong slug/id is a configuration error.
Raised when the startup is not found for this account (HTTP 404). Non-retryable — wrong slug/id is a configuration error.